# 2023-09-11 - Base Root Gauge Factory

Deployment of the `BaseRootGaugeFactory`, for stakeless gauges that bridge funds to their Base counterparts.
This uses the same L1StandardBridge as Optimism, and has no special requirements.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`BaseRootGaugeFactory` artifact](./artifact/BaseRootGaugeFactory.json)
